@@ -14,6 +14,7 @@ from autoconfiguration.exceptions.config_class_errors import (
 )
 from autoconfiguration.exceptions.config_dir_errors import ConfigDirNotFoundError
 from autoconfiguration.exceptions.config_file_errors import NoConfigFilesFoundError
+from autoconfiguration.helpers.modify_class import Constants
 
 LOG = logging.getLogger(__name__)
 
@@ -22,10 +23,6 @@ CONFIG_PREFIX = "config-"
 GLOBAL_CONFIG = f"config{CONFIG_EXTENSION}"
 
 
-class _Constants:
-    pass
-
-
 def init(*args: str, config_class: Type, config_dir: str = "config"):
     """
     Initializes the passed config class with the values of the *.ini files.
@@ -44,9 +41,9 @@ def init(*args: str, config_class: Type, config_dir: str = "config"):
     :returns: The initialized config class instance containing the values of the
         config files
     """
-    if hasattr(_Constants, "config_instance") and _Constants.config_instance:
+    if hasattr(Constants, "config_instance") and Constants.config_instance:
         LOG.debug("Config was already initialized. Returning existing instance.")
-        return _Constants.config_instance
+        return Constants.config_instance
 
     if not dataclasses.is_dataclass(config_class) or not all(
         dataclasses.is_dataclass(field.type)
@@ -63,7 +60,6 @@ def init(*args: str, config_class: Type, config_dir: str = "config"):
     LOG.info("The following config files were found: %s", config_files)
 
     instance = create_config_instance(config_class, config_files)
-    _Constants.config_instance = instance
     return instance
 
 
@@ -74,12 +70,20 @@ def get():
     :returns: The initialized instance of the config class
     :raise ConfigNotInitializedError: If the config class was not initialized
     """
-    if not hasattr(_Constants, "config_instance") or not _Constants.config_instance:
+    if not hasattr(Constants, "config_instance") or not Constants.config_instance:
         raise ConfigNotInitializedError()
-    return _Constants.config_instance
+    return Constants.config_instance
 
 
 def _validate_config_files(*args: str, config_dir: str) -> Tuple[str, ...]:
+    """
+    Checks if all passed config files exist in the passed config dir and returns a
+    tuple containing the paths of the config files.
+
+    :param args: The config files
+    :param config_dir: The config dir
+    :return: A tuple containing the paths of the config files
+    """
     if not args:
         return (os.path.join(config_dir, GLOBAL_CONFIG),)
 
@@ -108,6 +112,13 @@ def _validate_config_files(*args: str, config_dir: str) -> Tuple[str, ...]:
 
 
 def _get_correct_config_filename(filename: str):
+    """
+    Returns the full filename of the config file. The full filename begins with
+    'config-' and ends with '.ini'.
+
+    :param filename: Part of a config filename
+    :return: The full config filename
+    """
     return (
         ("" if filename.startswith(CONFIG_PREFIX) else CONFIG_PREFIX)
         + filename
@@ -115,5 +126,10 @@ def _get_correct_config_filename(filename: str):
     )
 
 
-def _reset():
-    _Constants.config_instance = None
+def reset():
+    """
+    Resets the instance of the config class. This should only be used in test setups
+    because it should not be necessary to reinitialize the instance.
+    """
+    if hasattr(Constants, "config_instance"):
+        del Constants.config_instance
